# Byteflow Webflow

Webflow connectors for Bytewax.

This connector offers 1 sink:

* `WebflowCollectionSink` - inserts or updates a specified Webflow Collection.

## Installation

This package is available via [PyPi](https://pypi.org/project/bytewax-webflow) as
`bytewax-webflow` and can be installed via your package manager of choice.

## Usage

TBD

## License

Licensed under the [MIT License](./LICENSE).
